@@ -19,18 +19,18 @@ context 'Helpers' do
 
   context 'URIs and Paths' do
     test 'rootname should return file name without extension' do
-      assert_equal 'master', Asciidoctor::Helpers.rootname('master.adoc')
-      assert_equal 'docs/master', Asciidoctor::Helpers.rootname('docs/master.adoc')
+      assert_equal 'main', Asciidoctor::Helpers.rootname('main.adoc')
+      assert_equal 'docs/main', Asciidoctor::Helpers.rootname('docs/main.adoc')
     end
 
     test 'rootname should file name if it has no extension' do
-      assert_equal 'master', Asciidoctor::Helpers.rootname('master')
-      assert_equal 'docs/master', Asciidoctor::Helpers.rootname('docs/master')
+      assert_equal 'main', Asciidoctor::Helpers.rootname('main')
+      assert_equal 'docs/main', Asciidoctor::Helpers.rootname('docs/main')
     end
 
     test 'rootname should ignore dot not in last segment' do
-      assert_equal 'include.d/master', Asciidoctor::Helpers.rootname('include.d/master')
-      assert_equal 'include.d/master', Asciidoctor::Helpers.rootname('include.d/master.adoc')
+      assert_equal 'include.d/main', Asciidoctor::Helpers.rootname('include.d/main')
+      assert_equal 'include.d/main', Asciidoctor::Helpers.rootname('include.d/main.adoc')
     end
 
     test 'extname? should return whether path contains an extname' do
@@ -76,7 +76,7 @@ context 'Helpers' do
         Asciidoctor::Helpers.class_for_name 'InvalidModule::InvalidClass'
         flunk 'Expecting RuntimeError to be raised'
       rescue NameError => e
-        assert_equal 'Could not resolve class for name: InvalidModule::InvalidClass', e.message
+        assert_match %r/^Could not resolve class for name: InvalidModule::InvalidClass$/, e.message
       end
     end
 
@@ -85,7 +85,7 @@ context 'Helpers' do
         Asciidoctor::Helpers.class_for_name 'foobar'
         flunk 'Expecting RuntimeError to be raised'
       rescue NameError => e
-        assert_equal 'Could not resolve class for name: foobar', e.message
+        assert_match %r/^Could not resolve class for name: foobar$/, e.message
       end
     end
 
@@ -94,7 +94,7 @@ context 'Helpers' do
         Asciidoctor::Helpers.class_for_name 'Asciidoctor::Extensions::String'
         flunk 'Expecting RuntimeError to be raised'
       rescue NameError => e
-        assert_equal 'Could not resolve class for name: Asciidoctor::Extensions::String', e.message
+        assert_match %r/^Could not resolve class for name: Asciidoctor::Extensions::String$/, e.message
       end
     end
 
@@ -103,7 +103,7 @@ context 'Helpers' do
         Asciidoctor::Helpers.class_for_name 'Asciidoctor::Extensions'
         flunk 'Expecting RuntimeError to be raised'
       rescue NameError => e
-        assert_equal 'Could not resolve class for name: Asciidoctor::Extensions', e.message
+        assert_match %r/^Could not resolve class for name: Asciidoctor::Extensions$/, e.message
       end
     end
 
@@ -124,7 +124,7 @@ context 'Helpers' do
         Asciidoctor::Helpers.resolve_class 'Asciidoctor::Extensions::String'
         flunk 'Expecting RuntimeError to be raised'
       rescue NameError => e
-        assert_equal 'Could not resolve class for name: Asciidoctor::Extensions::String', e.message
+        assert_match %r/^Could not resolve class for name: Asciidoctor::Extensions::String$/, e.message
       end
     end
   end
